Method: Redis::Distributed#pfmerge

Defined in:
lib/redis/distributed.rb

#pfmerge(dest_key, *source_key) ⇒ Object

Merge multiple HyperLogLog values into an unique value that will approximate the cardinality of the union of the observed Sets of the source HyperLogLog structures.



994
995
996
997
998
# File 'lib/redis/distributed.rb', line 994

def pfmerge(dest_key, *source_key)
  ensure_same_node(:pfmerge, [dest_key, *source_key]) do |node|
    node.pfmerge(dest_key, *source_key)
  end
end