Method: Redis::Distributed#zdiffstore
- Defined in:
- lib/redis/distributed.rb
#zdiffstore(destination, *keys, **options) ⇒ Object
Compute the difference between the first and all successive input sorted sets and store the resulting sorted set in a new key.
796 797 798 799 800 801 |
# File 'lib/redis/distributed.rb', line 796 def zdiffstore(destination, *keys, **) keys.flatten!(1) ensure_same_node(:zdiffstore, [destination] + keys) do |node| node.zdiffstore(destination, keys, **) end end |