Method: Redis::Client#call_pipeline
- Defined in:
- lib/redis/client.rb
#call_pipeline(pipeline) ⇒ Object
118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/redis/client.rb', line 118 def call_pipeline(pipeline) with_reconnect pipeline.with_reconnect? do begin pipeline.finish(call_pipelined(pipeline.commands)) rescue ConnectionError => e return nil if pipeline.shutdown? # Assume the pipeline was sent in one piece, but execution of # SHUTDOWN caused none of the replies for commands that were executed # prior to it from coming back around. raise e end end end |